@@ -8,7 +8,7 @@ class UltraSafeCipher():
         random.seed(None)
         first = random.choice([i for i in range(self.seed,self.seed**2)])
         last = first-self.dif if first > self.dif else first+self.dif
-        return (first,last) if first < last else last,first
+        return (first,last) if first < last else (last,first)
 
     def encrypt(self, plaintext):
         (first,last) = self.gen()
